@@ -1066,6 +1066,7 @@ doexpand(struct expstate *es, struct place *p, char *buf, size_t len)
 	char *s;
 	size_t x;
 	bool inquote = false;
+	char quote = '\0';
 
 	while (len > 0) {
 		x = strspn(buf, ws);
@@ -1107,35 +1108,39 @@ doexpand(struct expstate *es, struct place *p, char *buf, size_t len)
 			continue;
 		}
 
-		if (buf[0] == '(') {
+		if (!inquote && buf[0] == '(') {
 			expand_got_lparen(es, p, buf, 1);
 			buf++;
 			len--;
 			continue;
 		}
 
-		if (buf[0] == ')') {
+		if (!inquote && buf[0] == ')') {
 			expand_got_rparen(es, p, buf, 1);
 			buf++;
 			len--;
 			continue;
 		}
 
-		if (buf[0] == ',') {
+		if (!inquote && buf[0] == ',') {
 			expand_got_comma(es, p, buf, 1);
 			buf++;
 			len--;
 			continue;
 		}
 
-		if (len > 1 && buf[0] == '\\' && buf[1] == '"') {
+		if (len > 1 && buf[0] == '\\' &&
+		    (buf[1] == '"' || buf[1] == '\'')) {
 			expand_got_other(es, p, buf, 2);
 			buf += 2;
 			len -= 2;
 			continue;
 		}
-		if (buf[0] == '"') {
-			inquote = !inquote;
+		if (!inquote && (buf[0] == '"' || buf[0] == '\'')) {
+			inquote = true;
+			quote = buf[0];
+		} else if (inquote && buf[0] == quote) {
+			inquote = false;
 		}
 
 		expand_got_other(es, p, buf, 1);
