@@ -101,6 +101,7 @@ filter_output(const char *buf, size_t len)
 	size_t pos, start;
 	bool inesc = false;
 	bool inquote = false;
+	char quote = '\0';
 
 	start = 0;
 	for (pos = 0; pos < len - 1; pos++) {
@@ -136,8 +137,11 @@ filter_output(const char *buf, size_t len)
 			inesc = false;
 		} else if (buf[pos] == '\\') {
 			inesc = true;
-		} else if (buf[pos] == '"') {
-			inquote = !inquote;
+		} else if (!inquote && (buf[pos] == '"' || buf[pos] == '\'')) {
+			inquote = true;
+			quote = buf[pos];
+		} else if (inquote && buf[pos] == quote) {
+			inquote = false;
 		}
 	}
 	pos++;
